#### Импорт компонента

В файле `composer.json` проекта прописать

    "repositories": {
        "gitlab.iwayex.com/45": {
            "type": "composer",
            "url": "https://gitlab.iwayex.com/api/v4/group/45/-/packages/composer/packages.json"
        }
    }

и выполнить команду `composer require iwaydev/rbac-client`

#### Настройка компонента

В `.env` файлы для каждого стейджа прописываем переменные окружения для доступа к сервису RBAC:

    RBAC_URL=http://api.rbac.local:72
    RBAC_API_VERSION=v1
    RBAC_PROJECT_NAME=service
    RBAC_CACHE_LIFETIME=3600

Где:

- `RBAC_URL` - URL RBAC
- `RBAC_API_VERSION` - версия используемого апи
- `RBAC_PROJECT_NAME` - Название текущего проекта, как он прописан в сервисе RBAC
- `RBAC_CACHE_LIFETIME` - Время, в секундах, на которое будут кэшироваться ответы

В `app.php` файле конфигов зарегистрировать провайдер

    Iwaydev\Rbac\RbacServiceProvider::class,

Опубликовать конфиги

    make artis q="vendor:publish --provider=\"Iwaydev\Rbac\RbacServiceProvider\" --tag=config --force"

Накатить миграции, если нужно

    make artis q="vendor:publish --provider=\"Iwaydev\Rbac\RbacServiceProvider\" --tag=migrations --force"
    make artis q="migrate"

В `api.php` файле роутов прописать URL контроллера

    Route::prefix('/v1')->namespace('v1')
        ->group(function () {
            //Конфиги других роутов
            Route::prefix('rbac')->group(function () {
                Route::post('/update-permissions', '\Iwaydev\Rbac\Http\Controllers\RbacController@updatePermissions');
            });
        });
    
В классе `EventServiceProvider` в массиве свойства `listen` зарегистрировать события

    /**
     * The event listener mappings for the application.
     *
     * @var array
     */
    protected $listen = [
        //Другие события
        Iwaydev\Rbac\Events\UpdatePermissions::class => [
            Iwaydev\Rbac\Listeners\UpdatePermissions::class
        ]
    ];
    
Если нужно переопределить дефолтное логирование,
то в файле конфигов `logging.php` нужно создать таргет с именем `rbac`:

```
...
'channels' => [
    ...
    'rbac' => [
        'driver' => 'daily',
        'path' => storage_path('logs/new-path/for-file.log'),
        'level' => 'debug',
        'days' => 14,
        'permission' => 0777
    ],
]
```

Для локального проекта в файле докера `dev.stack.yml` для конейнера `php` в параметре `extra_hosts` укажите `- "api.rbac.local:{{IP_ADDRESS}}"`

Для проверки роли пользователя
    
    Iwaydev\Rbac\Rbac::hasRole(10001, 'test.role')
    Iwaydev\Rbac\Rbac::hasRole(10001, ['test.role', 'test.role2'])

Для проверки доступа пользователя
    
    Iwaydev\Rbac\Rbac::can(10001, 'test.permission')
    Iwaydev\Rbac\Rbac::can(10001, ['test.permission', 'test.permission2'])