<?php

namespace Iwaydev\Rbac\Events;

use Illuminate\Broadcasting\InteractsWithSockets;
use Illuminate\Broadcasting\PrivateChannel;
use Illuminate\Foundation\Events\Dispatchable;
use Illuminate\Queue\SerializesModels;
use Iwaydev\Rbac\Components\RbacClient;
use Psr\Log\LoggerInterface;

/**
 * Событие обновления прав доступа
 *
 * Class UpdatePermissions
 *
 * @package Rbac\Events
 */
class UpdatePermissions
{
    use Dispatchable;
    use InteractsWithSockets;
    use SerializesModels;

    /** @var LoggerInterface|null Логгер */
    private ?LoggerInterface $logger;
    /** @var RbacClient Клиент для общения с сервисом RBAC */
    private RbacClient $rbacClient;

    /**
     * Create a new event instance.
     *
     * @param RbacClient $rbacClient Клиент для общения с сервисом RBAC
     * @param LoggerInterface|null $logger Логгер
     */
    public function __construct(RbacClient $rbacClient, ?LoggerInterface $logger = null)
    {
        $this->rbacClient = $rbacClient;
        $this->logger = $logger;
    }

    /**
     * Get the channels the event should broadcast on.
     *
     * @return \Illuminate\Broadcasting\Channel|array
     */
    public function broadcastOn()
    {
        return new PrivateChannel('rbac-update-permissions');
    }

    /**
     * Получение логгера
     *
     * @return LoggerInterface
     */
    public function getLogger(): ?LoggerInterface
    {
        return $this->logger;
    }

    /**
     * Возвращает клиент для общения с сервисом RBAC
     *
     * @return RbacClient
     */
    public function getRbacClient(): RbacClient
    {
        return $this->rbacClient;
    }
}
